﻿using System.Runtime.Serialization;
using System.Text.Json.Serialization;

namespace Fido2NetLib.Objects;

/// <summary>
/// AttestationConveyancePreference
/// https://www.w3.org/TR/webauthn-2/#enum-attestation-convey
/// </summary>
[JsonConverter(typeof(FidoEnumConverter<AttestationConveyancePreference>))]
public enum AttestationConveyancePreference
{
    /// <summary>
    /// This value indicates that the Relying Party is not interested in authenticator attestation. For example, in order to potentially avoid having to obtain user consent to relay identifying information to the Relying Party, or to save a roundtrip to an Attestation CA.
    /// This is the default value.
    /// </summary>
    [EnumMember(Value = "none")]
    None,

    /// <summary>
    /// This value indicates that the Relying Party prefers an attestation conveyance yielding verifiable attestation statements, but allows the client to decide how to obtain such attestation statements. The client MAY replace the authenticator-generated attestation statements with attestation statements generated by an Anonymization CA, in order to protect the user’s privacy, or to assist Relying Parties with attestation verification in a heterogeneous ecosystem.
    /// </summary>
    [EnumMember(Value = "indirect")]
    Indirect,

    /// <summary>
    /// This value indicates that the Relying Party wants to receive the attestation statement as generated by the authenticator.
    /// </summary>
    [EnumMember(Value = "direct")]
    Direct,

    /// <summary>
    /// This value indicates that the Relying Party wants to receive an attestation statement that may include uniquely identifying information.
    /// </summary>
    [EnumMember(Value = "enterprise")]
    Enterprise
}
